@@ -35,9 +35,7 @@
 
 #include <MimeTreeParser/ObjectTreeParser>
 #include <MimeTreeParser/SimpleObjectTreeSource>
-#ifndef QT_NO_CURSOR
-#include <Libkdepim/KCursorSaver>
-#endif
+#include <KCursorSaver>
 #include <Sonnet/DictionaryComboBox>
 #include <KIdentityManagement/Identity>
 
@@ -157,7 +155,7 @@ void ComposerViewBase::setMessage(const KMime::Message::Ptr &msg, bool allowDecr
     // First, we copy the message and then parse it to the object tree parser.
     // The otp gets the message text out of it, in textualContent(), and also decrypts
     // the message if necessary.
-    KMime::Content *msgContent = new KMime::Content;
+    auto *msgContent = new KMime::Content;
     msgContent->setContent(m_msg->encodedContent());
     msgContent->parse();
     MimeTreeParser::SimpleObjectTreeSource emptySource;
@@ -210,7 +208,7 @@ void ComposerViewBase::updateTemplate(const KMime::Message::Ptr &msg)
     // First, we copy the message and then parse it to the object tree parser.
     // The otp gets the message text out of it, in textualContent(), and also decrypts
     // the message if necessary.
-    KMime::Content *msgContent = new KMime::Content;
+    auto *msgContent = new KMime::Content;
     msgContent->setContent(msg->encodedContent());
     msgContent->parse();
     MimeTreeParser::SimpleObjectTreeSource emptySource;
@@ -290,10 +288,7 @@ void ComposerViewBase::send(MessageComposer::MessageSender::SendMethod method, M
     mSendMethod = method;
     mSaveIn = saveIn;
 
-#ifndef QT_NO_CURSOR
-    KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
-
+    KCursorSaver saver(Qt::WaitCursor);
     const KIdentityManagement::Identity identity = identityManager()->identityForUoid(m_identityCombo->currentIdentity());
 
     if (identity.attachVcard() && m_attachmentController->attachOwnVcard()) {
@@ -347,7 +342,10 @@ void ComposerViewBase::send(MessageComposer::MessageSender::SendMethod method, M
     }
 
     if (mSendMethod == MessageComposer::MessageSender::SendImmediate && checkMailDispatcher) {
-        MessageComposer::Util::sendMailDispatcherIsOnline(m_parentWidget);
+        if (!MessageComposer::Util::sendMailDispatcherIsOnline(m_parentWidget)) {
+            qCWarning(MESSAGECOMPOSER_LOG) << "Impossible to set sendmaildispatcher online. Please verify it";
+            return;
+        }
     }
 
     readyForSending();
@@ -373,7 +371,7 @@ void ComposerViewBase::readyForSending()
     }
 
     // first, expand all addresses
-    MessageComposer::EmailAddressResolveJob *job = new MessageComposer::EmailAddressResolveJob(this);
+    auto *job = new MessageComposer::EmailAddressResolveJob(this);
     const KIdentityManagement::Identity identity = identityManager()->identityForUoid(m_identityCombo->currentIdentity());
     if (!identity.isNull()) {
         job->setDefaultDomainName(identity.defaultDomainName());
@@ -480,7 +478,7 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
     // if so, we create a composer per format
     // if we aren't signing or encrypting, this just returns a single empty message
     if (m_neverEncrypt && mSaveIn != MessageComposer::MessageSender::SaveInNone && !mSendLaterInfo) {
-        MessageComposer::Composer *composer = new MessageComposer::Composer;
+        auto *composer = new MessageComposer::Composer;
         composer->setNoCrypto(true);
         m_composers.append(composer);
     } else {
@@ -737,12 +735,12 @@ QVector< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(
                 continue;
             }
 
-            MessageComposer::Composer *composer = new MessageComposer::Composer;
+            auto *composer = new MessageComposer::Composer;
 
             if (encryptSomething) {
                 std::vector<Kleo::KeyResolver::SplitInfo> encData = keyResolver->encryptionItems(concreteFormat);
                 std::vector<Kleo::KeyResolver::SplitInfo>::iterator it;
-                std::vector<Kleo::KeyResolver::SplitInfo>::iterator end(encData.end());
+                auto end(encData.end());
                 QVector<QPair<QStringList, std::vector<GpgME::Key> > > data;
                 data.reserve(encData.size());
                 for (it = encData.begin(); it != end; ++it) {
@@ -765,7 +763,7 @@ QVector< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(
             composers.append(composer);
         }
     } else {
-        MessageComposer::Composer *composer = new MessageComposer::Composer;
+        auto *composer = new MessageComposer::Composer;
         composers.append(composer);
         //If we canceled sign or encrypt be sure to change status in attachment.
         markAllAttachmentsForSigning(false);
@@ -891,7 +889,7 @@ void ComposerViewBase::fillInfoPart(MessageComposer::InfoPart *infoPart, Compose
 void ComposerViewBase::slotSendComposeResult(KJob *job)
 {
     Q_ASSERT(dynamic_cast< MessageComposer::Composer * >(job));
-    MessageComposer::Composer *composer = static_cast< MessageComposer::Composer * >(job);
+    auto *composer = static_cast< MessageComposer::Composer * >(job);
     if (composer->error() != MessageComposer::Composer::NoError) {
         qCDebug(MESSAGECOMPOSER_LOG) << "compose job might have error: " << job->error() << " errorString: " << job->errorString();
     }
@@ -948,7 +946,7 @@ void ComposerViewBase::saveRecentAddresses(const KMime::Message::Ptr &msg)
 void ComposerViewBase::queueMessage(const KMime::Message::Ptr &message, MessageComposer::Composer *composer)
 {
     const MessageComposer::InfoPart *infoPart = composer->infoPart();
-    MailTransport::MessageQueueJob *qjob = new MailTransport::MessageQueueJob(this);
+    auto *qjob = new MailTransport::MessageQueueJob(this);
     qjob->setMessage(message);
     qjob->transportAttribute().setTransportId(infoPart->transportId());
     if (mSendMethod == MessageComposer::MessageSender::SendLater) {
@@ -990,7 +988,7 @@ void ComposerViewBase::queueMessage(const KMime::Message::Ptr &message, MessageC
 void ComposerViewBase::slotQueueResult(KJob *job)
 {
     m_pendingQueueJobs--;
-    MailTransport::MessageQueueJob *qjob = static_cast<MailTransport::MessageQueueJob * >(job);
+    auto *qjob = static_cast<MailTransport::MessageQueueJob * >(job);
     qCDebug(MESSAGECOMPOSER_LOG) << "mPendingQueueJobs" << m_pendingQueueJobs;
     Q_ASSERT(m_pendingQueueJobs >= 0);
 
@@ -1166,7 +1164,7 @@ void ComposerViewBase::slotAutoSaveComposeResult(KJob *job)
     using MessageComposer::Composer;
 
     Q_ASSERT(dynamic_cast< Composer * >(job));
-    Composer *composer = static_cast< Composer * >(job);
+    auto *composer = static_cast< Composer * >(job);
 
     if (composer->error() == Composer::NoError) {
         Q_ASSERT(m_composers.contains(composer));
@@ -1279,13 +1277,13 @@ void ComposerViewBase::saveMessage(const KMime::Message::Ptr &message, MessageCo
             break;
         }
 
-        Akonadi::CollectionFetchJob *saveMessageJob = new Akonadi::CollectionFetchJob(target, Akonadi::CollectionFetchJob::Base);
+        auto *saveMessageJob = new Akonadi::CollectionFetchJob(target, Akonadi::CollectionFetchJob::Base);
         saveMessageJob->setProperty("Akonadi::Item", QVariant::fromValue(item));
         QObject::connect(saveMessageJob, &Akonadi::CollectionFetchJob::result, this, &ComposerViewBase::slotSaveMessage);
     } else {
         // preinitialize with the default collections
         target = defaultSpecialTarget();
-        Akonadi::ItemCreateJob *create = new Akonadi::ItemCreateJob(item, target, this);
+        auto *create = new Akonadi::ItemCreateJob(item, target, this);
         connect(create, &Akonadi::ItemCreateJob::result, this, &ComposerViewBase::slotCreateItemResult);
         ++m_pendingQueueJobs;
     }
@@ -1305,7 +1303,7 @@ void ComposerViewBase::slotSaveMessage(KJob *job)
             target = fetchJob->collections().at(0);
         }
     }
-    Akonadi::ItemCreateJob *create = new Akonadi::ItemCreateJob(item, target, this);
+    auto *create = new Akonadi::ItemCreateJob(item, target, this);
     connect(create, &Akonadi::ItemCreateJob::result, this, &ComposerViewBase::slotCreateItemResult);
     ++m_pendingQueueJobs;
 }
@@ -1344,9 +1342,10 @@ void ComposerViewBase::slotCreateItemResult(KJob *job)
 
     Akonadi::Item::Id id = -1;
     if (mSendLaterInfo) {
-        Akonadi::ItemCreateJob *createJob = static_cast<Akonadi::ItemCreateJob *>(job);
+        auto *createJob = static_cast<Akonadi::ItemCreateJob *>(job);
         const Akonadi::Item item = createJob->item();
         if (item.isValid()) {
+            id = item.id();
             addSendLaterItem(item);
         }
     }
@@ -1417,7 +1416,7 @@ void ComposerViewBase::addAttachmentPart(KMime::Content *partToAttach)
 
 MessageComposer::Composer *ComposerViewBase::createSimpleComposer()
 {
-    MessageComposer::Composer *composer = new MessageComposer::Composer;
+    auto *composer = new MessageComposer::Composer;
     fillGlobalPart(composer->globalPart());
     m_editor->fillComposerTextPart(composer->textPart());
     fillInfoPart(composer->infoPart(), UseUnExpandedRecipients);
@@ -1619,7 +1618,7 @@ void ComposerViewBase::setFcc(const Akonadi::Collection &fccCollection)
     } else {
         m_fccCollection = fccCollection;
     }
-    Akonadi::CollectionFetchJob *const checkFccCollectionJob
+    auto *const checkFccCollectionJob
         = new Akonadi::CollectionFetchJob(fccCollection, Akonadi::CollectionFetchJob::Base);
     connect(checkFccCollectionJob, &KJob::result, this, &ComposerViewBase::slotFccCollectionCheckResult);
 }
@@ -1811,9 +1810,7 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
     case Kleo::Ask:
     {
         // the user wants to be asked or has to be asked
-#ifndef QT_NO_CURSOR
-        KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+        KCursorSaver saver(Qt::WaitCursor);
         const QString msg = i18n("Examination of the recipient's signing preferences "
                                  "yielded that you be asked whether or not to sign "
                                  "this message.\n"
@@ -1841,9 +1838,7 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
     case Kleo::Conflict:
     {
         // warn the user that there are conflicting signing preferences
-#ifndef QT_NO_CURSOR
-        KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+        KCursorSaver saver(Qt::WaitCursor);
         const QString msg = i18n("There are conflicting signing preferences "
                                  "for these recipients.\n"
                                  "Sign this message?");
@@ -1869,9 +1864,7 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
     }
     case Kleo::Impossible:
     {
-#ifndef QT_NO_CURSOR
-        KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+        KCursorSaver saver(Qt::WaitCursor);
         const QString msg = i18n("You have requested to sign this message, "
                                  "but no valid signing keys have been configured "
                                  "for this identity.");
@@ -1890,9 +1883,7 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
 
     if (!sign || !doSignCompletely) {
         if (MessageComposer::MessageComposerSettings::self()->cryptoWarningUnsigned()) {
-#ifndef QT_NO_CURSOR
-            KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+            KCursorSaver saver(Qt::WaitCursor);
             const QString msg = sign && !doSignCompletely
                                 ? i18n("Some parts of this message will not be signed.\n"
                                        "Sending only partially signed messages might violate site policy.\n"
@@ -1946,9 +1937,7 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely, Kleo:
     case Kleo::Ask:
     {
         // the user wants to be asked or has to be asked
-#ifndef QT_NO_CURSOR
-        KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+        KCursorSaver saver(Qt::WaitCursor);
         const QString msg = opportunistic
                             ? i18n("Valid trusted encryption keys were found for all recipients.\n"
                                    "Encrypt this message?")
@@ -1983,9 +1972,7 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely, Kleo:
     case Kleo::Conflict:
     {
         // warn the user that there are conflicting encryption preferences
-#ifndef QT_NO_CURSOR
-        KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+        KCursorSaver saver(Qt::WaitCursor);
         const QString msg = i18n("There are conflicting encryption preferences "
                                  "for these recipients.\n"
                                  "Encrypt this message?");
@@ -2011,9 +1998,7 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely, Kleo:
     }
     case Kleo::Impossible:
     {
-#ifndef QT_NO_CURSOR
-        KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+        KCursorSaver saver(Qt::WaitCursor);
         const QString msg = i18n("You have requested to encrypt this message, "
                                  "and to encrypt a copy to yourself, "
                                  "but no valid trusted encryption keys have been "
@@ -2033,9 +2018,7 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely, Kleo:
 
     if (!encrypt || !doEncryptCompletely) {
         if (MessageComposer::MessageComposerSettings::self()->cryptoWarningUnencrypted()) {
-#ifndef QT_NO_CURSOR
-            KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+            KCursorSaver saver(Qt::WaitCursor);
             const QString msg = !doEncryptCompletely
                                 ? i18n("Some parts of this message will not be encrypted.\n"
                                        "Sending only partially encrypted messages might violate "
@@ -2086,7 +2069,7 @@ void ComposerViewBase::addFollowupReminder(const QString &messageId)
 {
     if (!messageId.isEmpty()) {
         if (mFollowUpDate.isValid()) {
-            MessageComposer::FollowupReminderCreateJob *job = new MessageComposer::FollowupReminderCreateJob;
+            auto *job = new MessageComposer::FollowupReminderCreateJob;
             job->setSubject(m_subject);
             job->setMessageId(messageId);
             job->setTo(mExpandedReplyTo.isEmpty() ? mExpandedTo.join(QLatin1Char(',')) : mExpandedReplyTo.join(QLatin1Char(',')));
