@@ -1,25 +1,13 @@
 /*
- * Copyright (c) 2010 Volker Krause <vkrause@kde.org>
+ * SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
  *
  * Based on kmail/kmcomposewin.cpp
- * Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+ * SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
  *
  * Based on KMail code by:
- * Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
+ * SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "signaturecontroller.h"
@@ -137,7 +125,7 @@ void SignatureController::insertSignatureHelper(KIdentityManagement::Signature::
 
     // Identity::signature() is not const, although it should be, therefore the
     // const_cast.
-    KIdentityManagement::Identity &ident = const_cast<KIdentityManagement::Identity &>(
+    auto &ident = const_cast<KIdentityManagement::Identity &>(
         d->m_identityCombo->identityManager()->identityForUoidOrDefault(
             d->m_identityCombo->currentIdentity()));
     const KIdentityManagement::Signature signature = ident.signature();
