@@ -7,7 +7,6 @@
 #include "messagefactoryreplyjob.h"
 #include "settings/messagecomposersettings.h"
 #include <TemplateParser/TemplateParserJob>
-#include <KIdentityManagement/IdentityManager>
 
 using namespace MessageComposer;
 
@@ -22,8 +21,9 @@ MessageFactoryReplyJob::~MessageFactoryReplyJob()
 
 void MessageFactoryReplyJob::start()
 {
-    TemplateParser::TemplateParserJob *parser = new TemplateParser::TemplateParserJob(mMsg, (mReplyAll ? TemplateParser::TemplateParserJob::ReplyAll : TemplateParser::TemplateParserJob::Reply), this);
+    auto *parser = new TemplateParser::TemplateParserJob(mMsg, (mReplyAll ? TemplateParser::TemplateParserJob::ReplyAll : TemplateParser::TemplateParserJob::Reply), this);
     connect(parser, &TemplateParser::TemplateParserJob::parsingDone, this, &MessageFactoryReplyJob::slotReplyDone);
+    connect(parser, &TemplateParser::TemplateParserJob::parsingFailed, this, &MessageFactoryReplyJob::slotReplyDone);
     parser->setIdentityManager(mIdentityManager);
     parser->setCharsets(MessageComposerSettings::self()->preferredCharsets());
     parser->setWordWrap(MessageComposerSettings::wordWrap(), MessageComposerSettings::lineWrapWidth());
