@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "attachmentfromurljobtest.h"
@@ -42,14 +29,14 @@ void AttachmentFromUrlJobTest::testAttachments_data()
     QTest::addColumn<QByteArray>("mimetype");
 
     // PATH_ATTACHMENTS is defined by CMake.
-    QTest::newRow("png image") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QString::fromLatin1("image.png"))
-                               << QString::fromLatin1("image.png")
+    QTest::newRow("png image") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("image.png"))
+                               << QStringLiteral("image.png")
                                << QByteArray("image/png");
-    QTest::newRow("pdf doc") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QString::fromLatin1("doc.pdf"))
-                             << QString::fromLatin1("doc.pdf")
+    QTest::newRow("pdf doc") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("doc.pdf"))
+                             << QStringLiteral("doc.pdf")
                              << QByteArray("application/pdf");
-    QTest::newRow("text file") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QString::fromLatin1("file.txt"))
-                               << QString::fromLatin1("file.txt")
+    QTest::newRow("text file") << QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("file.txt"))
+                               << QStringLiteral("file.txt")
                                << QByteArray("text/plain");
 }
 
@@ -64,7 +51,7 @@ void AttachmentFromUrlJobTest::testAttachments()
     QByteArray data = file.readAll();
     file.close();
 
-    AttachmentFromUrlJob *ljob = new AttachmentFromUrlJob(url, this);
+    auto *ljob = new AttachmentFromUrlJob(url, this);
     VERIFYEXEC(ljob);
     AttachmentPart::Ptr part = ljob->attachmentPart();
     delete ljob;
@@ -79,9 +66,9 @@ void AttachmentFromUrlJobTest::testAttachments()
 
 void AttachmentFromUrlJobTest::testAttachmentTooBig()
 {
-    const QUrl url = QUrl::fromLocalFile(PATH_ATTACHMENTS + QString::fromLatin1("doc.pdf"));
+    const QUrl url = QUrl::fromLocalFile(PATH_ATTACHMENTS + QLatin1String("doc.pdf"));
 
-    AttachmentFromUrlJob *ljob = new AttachmentFromUrlJob(url, this);
+    auto *ljob = new AttachmentFromUrlJob(url, this);
     ljob->setMaximumAllowedSize(1024);   // 1KiB, whereas the file is >9KiB.
     QVERIFY(!ljob->exec());
 }
@@ -89,11 +76,11 @@ void AttachmentFromUrlJobTest::testAttachmentTooBig()
 void AttachmentFromUrlJobTest::testAttachmentCharset()
 {
     const QByteArray charset("iso-8859-2");
-    const QString filename = QString::fromLatin1("file.txt");
+    const QString filename = QStringLiteral("file.txt");
     QUrl url = QUrl::fromLocalFile(PATH_ATTACHMENTS + filename);
     MessageCore::StringUtil::setEncodingFile(url, QString::fromLatin1(charset));
 
-    AttachmentFromUrlJob *ljob = new AttachmentFromUrlJob(url, this);
+    auto *ljob = new AttachmentFromUrlJob(url, this);
     VERIFYEXEC(ljob);
     AttachmentPart::Ptr part = ljob->attachmentPart();
     delete ljob;
