@@ -21,9 +21,9 @@ using namespace MessageViewer;
 DKIMManagerKeyWidget::DKIMManagerKeyWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
 
     mTreeWidget = new QTreeWidget(this);
     mTreeWidget->setObjectName(QStringLiteral("treewidget"));
@@ -32,7 +32,7 @@ DKIMManagerKeyWidget::DKIMManagerKeyWidget(QWidget *parent)
     mTreeWidget->setContextMenuPolicy(Qt::CustomContextMenu);
     mTreeWidget->setAlternatingRowColors(true);
 
-    KTreeWidgetSearchLine *searchLineEdit = new KTreeWidgetSearchLine(this, mTreeWidget);
+    auto *searchLineEdit = new KTreeWidgetSearchLine(this, mTreeWidget);
     searchLineEdit->setObjectName(QStringLiteral("searchlineedit"));
     searchLineEdit->setClearButtonEnabled(true);
     mainLayout->addWidget(searchLineEdit);
@@ -55,9 +55,9 @@ void DKIMManagerKeyWidget::restoreHeaders(const QByteArray &header)
     mTreeWidget->header()->restoreState(header);
 }
 
-void DKIMManagerKeyWidget::customContextMenuRequested(const QPoint &)
+void DKIMManagerKeyWidget::customContextMenuRequested(const QPoint &pos)
 {
-    QTreeWidgetItem *item = mTreeWidget->currentItem();
+    QTreeWidgetItem *item = mTreeWidget->itemAt(pos);
     QMenu menu(this);
     if (item) {
         menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Key"), this, [item]() {
@@ -87,7 +87,7 @@ void DKIMManagerKeyWidget::loadKeys()
 {
     const QVector<MessageViewer::KeyInfo> lst = DKIMManagerKey::self()->keys();
     for (const MessageViewer::KeyInfo &key : lst) {
-        QTreeWidgetItem *item = new QTreeWidgetItem(mTreeWidget);
+        auto *item = new QTreeWidgetItem(mTreeWidget);
         item->setText(0, key.domain);
         item->setText(1, key.selector);
         item->setText(2, key.keyValue);
@@ -98,6 +98,7 @@ void DKIMManagerKeyWidget::loadKeys()
 void DKIMManagerKeyWidget::saveKeys()
 {
     QVector<MessageViewer::KeyInfo> lst;
+    lst.reserve(mTreeWidget->topLevelItemCount());
     for (int i = 0, total = mTreeWidget->topLevelItemCount(); i < total; ++i) {
         QTreeWidgetItem *item = mTreeWidget->topLevelItem(i);
         const MessageViewer::KeyInfo info {item->text(2), item->text(1), item->text(0)};
