@@ -12,7 +12,6 @@
 #include <QUrl>
 
 #include <cassert>
-#include <QByteArray>
 #include <QTemporaryFile>
 #include <QDir>
 
@@ -38,6 +37,7 @@ void WebEnginePartHtmlWriter::begin()
     }
 
     delete mTempFile;
+    mTempFile = nullptr;
 
     BufferedHtmlWriter::begin();
     MessageViewer::WebEngineEmbedPart::self()->clear();
@@ -58,7 +58,7 @@ void WebEnginePartHtmlWriter::end()
         insertBodyStyle();
         mStyleBody.clear();
     }
-    if (data().size() > 2000000000) {
+    if (data().size() > 2000000) {
         qDebug() << " load big message ";
         mTempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/messageviewer_XXXXXX")+ QLatin1String(".html"));
         mTempFile->open();
