@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -22,7 +9,7 @@
 #include "messageviewer_debug.h"
 #include "settings/messageviewersettings.h"
 
-#include "kpimtextedit/richtexteditorwidget.h"
+#include <KPIMTextEdit/RichTextEditorWidget>
 
 #include <KLocalizedString>
 
@@ -46,10 +33,10 @@ ScamDetectionDetailsDialog::ScamDetectionDetailsDialog(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Details"));
     setAttribute(Qt::WA_DeleteOnClose);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    QPushButton *user1Button = new QPushButton(this);
+    auto *user1Button = new QPushButton(this);
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &ScamDetectionDetailsDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ScamDetectionDetailsDialog::reject);
@@ -86,9 +73,9 @@ void ScamDetectionDetailsDialog::slotSaveAs()
             QTextStream ts(&file);
             ts.setCodec("UTF-8");
             QString htmlStr = mDetails->toHtml();
-            htmlStr.replace(QLatin1String("meta name=\"qrichtext\" content=\"1\""),
+            htmlStr.replace(QLatin1String(R"(meta name="qrichtext" content="1")"),
                             QLatin1String(
-                                "meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
+                                R"(meta http-equiv="Content-Type" content="text/html; charset=UTF-8")"));
             ts <<  htmlStr;
             file.close();
         }
