@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2007, 2008 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007, 2008 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mimetreemodel.h"
@@ -57,16 +44,16 @@ public:
 
     QString descriptionForContent(KMime::Content *content)
     {
-        KMime::Message *const message = dynamic_cast<KMime::Message *>(content);
+        auto *const message = dynamic_cast<KMime::Message *>(content);
         if (message && message->subject(false)) {
-            return message->subject()->asUnicodeString();
+            return message->subject(false)->asUnicodeString();
         }
         const QString name = MimeTreeParser::NodeHelper::fileName(content);
         if (!name.isEmpty()) {
             return name;
         }
-        if (content->contentDescription(false)) {
-            const QString desc = content->contentDescription()->asUnicodeString();
+        if (auto ct = content->contentDescription(false)) {
+            const QString desc = ct->asUnicodeString();
             if (!desc.isEmpty()) {
                 return desc;
             }
@@ -76,17 +63,17 @@ public:
 
     QString mimeTypeForContent(KMime::Content *content)
     {
-        if (content->contentType(false)) {
-            return QString::fromLatin1(content->contentType()->mimeType());
+        if (auto ct = content->contentType(false)) {
+            return QString::fromLatin1(ct->mimeType());
         }
         return QString();
     }
 
     QString typeForContent(KMime::Content *content)
     {
-        if (content->contentType(false)) {
-            const QString contentMimeType = QString::fromLatin1(content->contentType()->mimeType());
-            auto mimeType = m_mimeDb.mimeTypeForName(contentMimeType);
+        if (auto ct = content->contentType(false)) {
+            const QString contentMimeType = QString::fromLatin1(ct->mimeType());
+            const auto mimeType = m_mimeDb.mimeTypeForName(contentMimeType);
             if (!mimeType.isValid()) {
                 return contentMimeType;
             }
@@ -106,13 +93,12 @@ public:
 
     QIcon iconForContent(KMime::Content *content)
     {
-        if (content->contentType(false)) {
+        if (auto ct = content->contentType(false)) {
             auto iconName
-                = MimeTreeParser::Util::iconNameForMimetype(QLatin1String(content->contentType()->
-                                                                          mimeType()));
+                = MimeTreeParser::Util::iconNameForMimetype(QLatin1String(ct->mimeType()));
 
             auto mimeType
-                = m_mimeDb.mimeTypeForName(QString::fromLatin1(content->contentType()->mimeType()));
+                = m_mimeDb.mimeTypeForName(QString::fromLatin1(ct->mimeType()));
             if (!mimeType.isValid()
                 || mimeType.name() == QLatin1String("application/octet-stream")) {
                 const QString name = descriptionForContent(content);
@@ -173,7 +159,7 @@ QModelIndex MimeTreeModel::index(int row, int column, const QModelIndex &parent)
         return createIndex(row, column, d->root);
     }
 
-    KMime::Content *parentContent = static_cast<KMime::Content *>(parent.internalPointer());
+    auto *parentContent = static_cast<KMime::Content *>(parent.internalPointer());
     if (!parentContent || parentContent->contents().count() <= row || row < 0) {
         return QModelIndex();
     }
@@ -186,7 +172,7 @@ QModelIndex MimeTreeModel::parent(const QModelIndex &index) const
     if (!index.isValid()) {
         return QModelIndex();
     }
-    KMime::Content *currentContent = static_cast<KMime::Content *>(index.internalPointer());
+    auto *currentContent = static_cast<KMime::Content *>(index.internalPointer());
     if (!currentContent) {
         return QModelIndex();
     }
@@ -213,7 +199,7 @@ int MimeTreeModel::rowCount(const QModelIndex &parent) const
     if (!parent.isValid()) {
         return 1;
     }
-    KMime::Content *parentContent = static_cast<KMime::Content *>(parent.internalPointer());
+    auto *parentContent = static_cast<KMime::Content *>(parent.internalPointer());
     if (parentContent) {
         return parentContent->contents().count();
     }
@@ -228,7 +214,7 @@ int MimeTreeModel::columnCount(const QModelIndex &parent) const
 
 QVariant MimeTreeModel::data(const QModelIndex &index, int role) const
 {
-    KMime::Content *content = static_cast<KMime::Content *>(index.internalPointer());
+    auto *content = static_cast<KMime::Content *>(index.internalPointer());
     if (!content) {
         return QVariant();
     }
@@ -260,14 +246,14 @@ QVariant MimeTreeModel::data(const QModelIndex &index, int role) const
         return d->mimeTypeForContent(content);
     }
     if (role == MainBodyPartRole) {
-        KMime::Message *topLevelMsg = dynamic_cast<KMime::Message *>(d->root);
+        auto *topLevelMsg = dynamic_cast<KMime::Message *>(d->root);
         if (!topLevelMsg) {
             return false;
         }
         return topLevelMsg->mainBodyPart() == content;
     }
     if (role == AlternativeBodyPartRole) {
-        KMime::Message *topLevelMsg = dynamic_cast<KMime::Message *>(d->root);
+        auto *topLevelMsg = dynamic_cast<KMime::Message *>(d->root);
         if (!topLevelMsg) {
             return false;
         }
@@ -299,7 +285,7 @@ QMimeData *MimeTreeModel::mimeData(const QModelIndexList &indexes) const
         if (index.column() != 0) {
             continue;
         }
-        KMime::Content *content = static_cast<KMime::Content *>(index.internalPointer());
+        auto *content = static_cast<KMime::Content *>(index.internalPointer());
         if (!content) {
             continue;
         }
@@ -308,7 +294,7 @@ QMimeData *MimeTreeModel::mimeData(const QModelIndexList &indexes) const
             continue;
         }
 
-        QTemporaryDir *tempDir = new QTemporaryDir; // Will remove the directory on destruction.
+        auto *tempDir = new QTemporaryDir; // Will remove the directory on destruction.
         d->tempDirs.append(tempDir);
         const QString fileName = tempDir->path() + QLatin1Char('/') + d->descriptionForContent(
             content);
@@ -328,7 +314,7 @@ QMimeData *MimeTreeModel::mimeData(const QModelIndexList &indexes) const
         urls.append(url);
     }
 
-    QMimeData *mimeData = new QMimeData;
+    auto *mimeData = new QMimeData;
     mimeData->setUrls(urls);
     return mimeData;
 }
