@@ -519,17 +519,13 @@ void Viewer::readConfig()
 
 QAbstractItemModel *Viewer::messageTreeModel() const
 {
-#ifndef QT_NO_TREEVIEW
     return d_func()->mMimePartTree->mimePartModel();
-#else
-    return nullptr;
-#endif
 }
 
 Akonadi::ItemFetchJob *Viewer::createFetchJob(const Akonadi::Item &item)
 {
     Q_D(Viewer);
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, d->mSession);
+    auto *job = new Akonadi::ItemFetchJob(item, d->mSession);
     job->fetchScope().fetchAllAttributes();
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     job->fetchScope().fetchFullPayload(true);
