@@ -592,6 +592,7 @@ private:
     bool mHtmlMailGlobalSetting = false;
     bool mHtmlLoadExternalDefaultSetting = false;
     bool mHtmlLoadExtOverride = false;
+    void assignMessageItem(const Akonadi::Item &item);
 public:
     KMime::Message::Ptr mMessage; //the current message, if it was set manually
     Akonadi::Item mMessageItem; //the message item from Akonadi
@@ -599,9 +600,7 @@ public:
     QSplitter *mSplitter = nullptr;
     QWidget *mBox = nullptr;
     HtmlStatusBar *mColorBar = nullptr;
-#ifndef QT_NO_TREEVIEW
     MimePartTreeView *mMimePartTree = nullptr;
-#endif
     MailWebEngineView *mViewer = nullptr;
     WebEngineViewer::FindBarWebEngineView *mFindBar = nullptr;
 
@@ -668,7 +667,7 @@ public:
     Akonadi::Session *mSession = nullptr;
     Akonadi::Monitor mMonitor;
     QSet<AbstractMessageLoadedHandler *> mMessageLoadedHandlers;
-    Akonadi::Item::Id mPreviouslyViewedItemId;
+    Akonadi::Item::Id mPreviouslyViewedItemId = -1;
 
     MessageViewer::ScamDetectionWarningWidget *mScamDetectionWarning = nullptr;
     MessageViewer::OpenSavedFileFolderWidget *mOpenSavedFileFolderWidget = nullptr;
